ams.opt.Var
===========

.. currentmodule:: ams.opt

.. autoclass:: Var

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Var.evaluate
       
       
          ~Var.get_idx
       
       
          ~Var.parse
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Var.class_name
      ~Var.n
      ~Var.shape
      ~Var.size
      ~Var.v
   
   